<?php
/*
Plugin Name: Recent Posts Dated Widget
Plugin URI: http://wordpress.org/support/topic/389933
Description: Displays recent posts including the post date. Beta version.
Version: 0.1
Author: J. Michael Ambrosio
Author URI: http://www.ambrosite.com
License: GPL2
*/

/**
 * Recent_Posts_Dated_Widget
 * Displays recent posts including the post date.
 *
 * Based on WP_Widget_Recent_Posts from wp-includes/default-widgets.php
 *
 * @since 0.1
 */
class Recent_Posts_Dated_Widget extends WP_Widget {

	function Recent_Posts_Dated_Widget() {
		$widget_ops = array('classname' => 'recent_entries_dated_widget', 'description' => __( "The most recent posts on your blog, including post dates.") );
		$this->WP_Widget('recent-posts-dated', __('Recent Posts Dated'), $widget_ops);
		$this->alt_option_name = 'recent_entries_dated_widget';

		add_action( 'save_post', array(&$this, 'flush_widget_cache') );
		add_action( 'deleted_post', array(&$this, 'flush_widget_cache') );
		add_action( 'switch_theme', array(&$this, 'flush_widget_cache') );
	}

	function widget($args, $instance) {
		$cache = wp_cache_get('recent_posts_dated_widget', 'widget');

		if ( !is_array($cache) )
			$cache = array();

		if ( isset($cache[$args['widget_id']]) ) {
			echo $cache[$args['widget_id']];
			return;
		}

		ob_start();
		extract($args);

		$title = apply_filters('widget_title', empty($instance['title']) ? __('Recent Posts') : $instance['title']);
		if ( !$number = (int) $instance['number'] )
			$number = 10;
		else if ( $number < 1 )
			$number = 1;
		else if ( $number > 15 )
			$number = 15;

		$r = new WP_Query(array('showposts' => $number, 'nopaging' => 0, 'post_status' => 'publish', 'caller_get_posts' => 1));
		if ($r->have_posts()) :
?>
		<?php echo $before_widget; ?>
		<?php if ( $title ) echo $before_title . $title . $after_title; ?>
		<ul class="recent-posts-dated">
		<?php  while ($r->have_posts()) : $r->the_post(); ?>
		<li> <a href="<?php the_permalink() ?>" title="<?php echo esc_attr(get_the_title() ? get_the_title() : get_the_ID()); ?>"><?php if ( get_the_title() ) the_title(); else the_ID(); ?></a><br/> <span class="date"><?php the_time(get_option('date_format')); ?></span></li>
		<?php endwhile; ?>
		</ul>
		<?php echo $after_widget; ?>
<?php
			wp_reset_query();  // Restore global post data stomped by the_post().
		endif;

		$cache[$args['widget_id']] = ob_get_flush();
		wp_cache_add('recent_posts_dated_widget', $cache, 'widget');
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);
		$instance['number'] = (int) $new_instance['number'];
		$this->flush_widget_cache();

		$alloptions = wp_cache_get( 'alloptions', 'options' );
		if ( isset($alloptions['recent_entries_dated_widget']) )
			delete_option('recent_entries_dated_widget');

		return $instance;
	}

	function flush_widget_cache() {
		wp_cache_delete('recent_posts_dated_widget', 'widget');
	}

	function form( $instance ) {
		$title = isset($instance['title']) ? esc_attr($instance['title']) : '';
		if ( !isset($instance['number']) || !$number = (int) $instance['number'] )
			$number = 5;
?>
		<p><label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:'); ?></label>
		<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $title; ?>" /></p>

		<p><label for="<?php echo $this->get_field_id('number'); ?>"><?php _e('Number of posts to show:'); ?></label>
		<input id="<?php echo $this->get_field_id('number'); ?>" name="<?php echo $this->get_field_name('number'); ?>" type="text" value="<?php echo $number; ?>" size="3" /><br />
		<small><?php _e('(at most 15)'); ?></small></p>
<?php
	}
}

/**
 * @since 0.1
 */
function Recent_Posts_Dated_init() {
	register_widget('Recent_Posts_Dated_Widget');
}

/**
 * @since 0.1
 */
add_action('widgets_init', 'Recent_Posts_Dated_init');

?>